@@ -102,7 +102,7 @@
 #define SCOTCH_DGRAPHBUILDGRID3DNGB26 1
 #define SCOTCH_DGRAPHBUILDGRID3DVERTLOAD 4
 #define SCOTCH_DGRAPHBUILDGRID3DEDGELOAD 8
-#endif /* SCOTCH_DGRAPHBUILDGRID3DMESH */
+#endif /* SCOTCH_DGRAPHBUILDGRID3DGRID */
 
 /*+ Integer type. +*/
 
